summaryrefslogtreecommitdiffstats
path: root/generic/tkInt.h
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-09 11:05:25 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-09 11:05:25 (GMT)
commite59d11829980b85d1a4c263d108f0a601fce5e5b (patch)
tree4909d393da1e0d6ebffb2e96915a5c1fca3cb051 /generic/tkInt.h
parent28c1f407a28c2c2f5824dba9c2ad233d25bd9500 (diff)
parent9c82b94f7f8be2ebc6cf88f55d08d6e087cff5a5 (diff)
downloadtk-e59d11829980b85d1a4c263d108f0a601fce5e5b.zip
tk-e59d11829980b85d1a4c263d108f0a601fce5e5b.tar.gz
tk-e59d11829980b85d1a4c263d108f0a601fce5e5b.tar.bz2
Merge 8.6
Diffstat (limited to 'generic/tkInt.h')
-rw-r--r--generic/tkInt.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/generic/tkInt.h b/generic/tkInt.h
index b700be7..530638a 100644
--- a/generic/tkInt.h
+++ b/generic/tkInt.h
@@ -861,9 +861,9 @@ typedef struct TkWindow {
#endif /* TK_USE_INPUT_METHODS */
char *geomMgrName; /* Records the name of the geometry manager. */
struct TkWindow *maintainerPtr;
/* The geometry master for this window. The
* value is NULL if the window has no master or
* if its master is its parent. */
} TkWindow;
/*
@@ -1221,10 +1221,12 @@ MODULE_SCOPE int Tk_WmObjCmd(ClientData clientData, Tcl_Interp *interp,
MODULE_SCOPE int Tk_GetDoublePixelsFromObj(Tcl_Interp *interp,
Tk_Window tkwin, Tcl_Obj *objPtr,
double *doublePtr);
-MODULE_SCOPE int TkSetGeometryMaster(Tcl_Interp *interp,
- Tk_Window tkwin, const char *master);
-MODULE_SCOPE void TkFreeGeometryMaster(Tk_Window tkwin,
- const char *master);
+#define TkSetGeometryContainer TkSetGeometryMaster
+MODULE_SCOPE int TkSetGeometryContainer(Tcl_Interp *interp,
+ Tk_Window tkwin, const char *name);
+#define TkFreeGeometryContainer TkFreeGeometryMaster
+MODULE_SCOPE void TkFreeGeometryContainer(Tk_Window tkwin,
+ const char *name);
MODULE_SCOPE void TkEventInit(void);
MODULE_SCOPE void TkRegisterObjTypes(void);
@@ -861,9 +861,9 @@ typedef struct TkWindow {
char *geomMgrName; /* Records the name of the geometry manager. */
struct TkWindow *maintainerPtr;
- /* The geometry master for this window. The
- * value is NULL if the window has no master or
- * if its master is its parent. */
+ /* The geometry container for this window. The
+ * value is NULL if the window has no container or
+ * if its container is its parent. */
} TkWindow;
/*